@@ -2,7 +2,7 @@ import doctest
 
 from insights.parsers import teamdctl_config_dump
 from insights.parsers.teamdctl_config_dump import TeamdctlConfigDump
-from insights.parsers.tests import test_empty_skip
+from insights.parsers.tests import skip_exception_check
 from insights.tests import context_wrap
 
 TEAMDCTL_CONFIG_DUMP_INFO = """
@@ -41,7 +41,7 @@ def test_teamdctl_state_dump():
 
 
 def test_teamdctl_state_dump_empty():
-    assert 'Empty output.' in test_empty_skip(TeamdctlConfigDump)
+    assert 'Empty output.' in skip_exception_check(TeamdctlConfigDump)
 
 
 def test_nmcli_doc_examples():
