@@ -178,6 +178,8 @@ class Specs(SpecSet):
     foreman_tasks_config = RegistryPoint(filterable=True)
     freeipa_healthcheck_log = RegistryPoint()
     fstab = RegistryPoint()
+    fw_devices = RegistryPoint()
+    fw_security = RegistryPoint()
     galera_cnf = RegistryPoint()
     gcp_instance_type = RegistryPoint()
     gcp_license_codes = RegistryPoint()
@@ -196,6 +198,7 @@ class Specs(SpecSet):
     gnocchi_conf = RegistryPoint(filterable=True)
     gnocchi_metricd_log = RegistryPoint(filterable=True)
     greenboot_status = RegistryPoint(filterable=True)
+    grubenv = RegistryPoint()
     grub_conf = RegistryPoint()
     grub_config_perms = RegistryPoint()
     grub_efi_conf = RegistryPoint()
@@ -230,6 +233,7 @@ class Specs(SpecSet):
     httpd_M = RegistryPoint(multi_output=True)
     httpd_on_nfs = RegistryPoint()
     httpd_ssl_access_log = RegistryPoint(filterable=True)
+    httpd_ssl_cert_enddate = RegistryPoint()
     httpd_ssl_error_log = RegistryPoint(filterable=True)
     httpd_V = RegistryPoint(multi_output=True)
     virt_uuid_facts = RegistryPoint()
