@@ -68,6 +68,8 @@ class InsightsArchiveSpecs(Specs):
     fcoeadm_i = simple_file("insights_commands/fcoeadm_-i")
     findmnt_lo_propagation = simple_file("insights_commands/findmnt_-lo_PROPAGATION")
     firewall_cmd_list_all_zones = simple_file("insights_commands/firewall-cmd_--list-all-zones")
+    fw_devices = simple_file("insights_commands/fwupdagent_get-devices")
+    fw_security = simple_file("insights_commands/fwupdagent_security_--force")
     gcp_license_codes = simple_file("insights_commands/python_-m_insights.tools.cat_--no-header_gcp_license_codes")
     getconf_page_size = simple_file("insights_commands/getconf_PAGE_SIZE")
     getenforce = simple_file("insights_commands/getenforce")
